proc ElasticBeamWSection2d {eleTag iNode jNode sectType E transfTag {Orient XX}} {
    global WSection
    global in
    set found 0
    foreach {section prop} [array get WSection $sectType] {
	set propList [split $prop]

	set A [expr [lindex $propList 0]*$in*$in]
	set Ixx [expr [lindex $propList 5]*$in*$in*$in*$in]
	set Iyy [expr [lindex $propList 6]*$in*$in*$in*$in]
	if {$Orient == "YY" } {
	    puts "element elasticBeamColumn $eleTag $iNode $jNode $A $E $Iyy $transfTag"
	    element elasticBeamColumn $eleTag $iNode $jNode $A $E $Iyy $transfTag
	} else {
	    puts "element elasticBeamColumn $eleTag $iNode $jNode $A $E $Ixx $transfTag"
	    element elasticBeamColumn $eleTag $iNode $jNode $A $E $Ixx $transfTag
	}
	set found 1
    }

    if {$found == 0} {
	puts "ElasticBeamWSection2d sectType: $sectType not found for e;e: $eleTag"
    }
}

proc ElasticSteelWSection2d {sectTag sectType E {Orient XX}} {
    global WSection
    global in
    set found 0
    foreach {section prop} [array get WSection $sectType] {
	set propList [split $prop]

	set A [expr [lindex $propList 0]*$in*$in]
	set Ixx [expr [lindex $propList 5]*$in*$in*$in*$in]
	set Iyy [expr [lindex $propList 6]*$in*$in*$in*$in]
	if {$Orient == "YY" } {
	    section Elastic $sectTag $E $A $Iyy
	    puts "section Elastic $sectTag $E $A $Iyy; # $sectType"
	} else {
	    section Elastic $sectTag $E $A $Ixx
	    puts "section Elastic $sectTag $E $A $Ixx; # $sectType"
	}
	set found 1
    }

    if {$found == 0} {
	puts "FiberSteelWSection2d sectType: $sectType not found for sectTag: $sectTag"
    }
}

proc FiberSteelWSection2d {sectTag sectType matTag {Orient XX}} {
    global WSection
    global in
    set found 0
    foreach {section prop} [array get WSection $sectType] {
	set propList [split $prop]

	set  d [expr [lindex $propList 1]*$in]
	set bf [expr [lindex $propList 2]*$in]
	set tw [expr [lindex $propList 3]*$in]
	set tf [expr [lindex $propList 4]*$in]

#	set Ixx [expr $tw*$d*$d*$d/12.0 + 2.0*(($bf-$tw)*$tf*($d-$tf)*($d-$tf)/4.0 + ($bf-$tw)*$tf*$tf*$tf/12.0)]
#	puts "Ixx: $Ixx IXX:[expr [lindex $propList 5]*$in*$in*$in*$in]"

	Wsection $sectTag $matTag $d $bf $tf $tw 10 1 1 10 $Orient
	puts "Wsection $sectTag $matTag $d $bf $tf $tw 10 1 1 10 $Orient; #sectType"
	set found 1
    }
    if {$found == 0} {
	puts "FiberSteelWSection2d sectType: $sectType not found for sectTag: $sectTag"
    }
}

proc ElasticSteelWSection2d {sectTag sectType E {Orient XX}} {
    global WSection
    global in
    global fileOut
    set found 0
    foreach {section prop} [array get WSection $sectType] {
	set propList [split $prop]

	set A [expr [lindex $propList 0]*$in*$in]
	set Ixx [expr [lindex $propList 5]*$in*$in*$in*$in]
	set Iyy [expr [lindex $propList 6]*$in*$in*$in*$in]
	if {$Orient == "YY" } {
	    section Elastic $sectTag $E $A $Iyy
	    puts $fileOut "section Elastic $sectTag $E $A $Iyy; # $sectType"
	} else {
	    section Elastic $sectTag $E $A $Ixx
	    puts $fileOut "section Elastic $sectTag $E $A $Ixx; # $sectType"
	}
	set found 1
    }

    if {$found == 0} {
	puts "FiberSteelWSection2d sectType: $sectType not found for sectTag: $sectTag"
    }
}


proc elasticBeamColumnWSection2d {eleTag iNode jNode sectType E transfTag {Orient XX}} {
    global WSection
    global in
    global fileOut
    set found 0
    foreach {section prop} [array get WSection $sectType] {
	set propList [split $prop]

	set A [expr [lindex $propList 0]*$in*$in]
	set Ixx [expr [lindex $propList 5]*$in*$in*$in*$in]
	set Iyy [expr [lindex $propList 6]*$in*$in*$in*$in]
	if {$Orient == "YY" } {
	    element elasticBeamColumn $eleTag $iNode $jNode $A $E $Iyy $transfTag
	    puts $fileOut "element elasticBeamColumn $eleTag $iNode $jNode $A $E $Iyy $transfTag"

	} else {
	    element elasticBeamColumn $eleTag $iNode $jNode $A $E $Ixx $transfTag
	    puts $fileOut "element elasticBeamColumn $eleTag $iNode $jNode $A $E $Ixx $transfTag"
	}
	set found 1
    }

    if {$found == 0} {
	puts "ElasticBeamWSection2d sectType: $sectType not found for e;e: $eleTag"
    }
}


proc Wsection { secID matID d bf tf tw nfdw nftw nfbf nftf {Orient ZZ}} {
    # ###################################################################
    # Wsection  $secID $matID $d $bf $tf $tw $nfdw $nftw $nfbf $nftf
    # ###################################################################
    # create a standard W section given the nominal section properties
    # written: Remo M. de Souza
    # date: 06/99
    # modified: 08/99  (according to the new general modelbuilder)
    # input parameters
    # secID - section ID number
    # matID - material ID number 
    # d  = nominal depth
    # tw = web thickness
    # bf = flange width
    # tf = flange thickness
    # nfdw = number of fibers along web depth 
    # nftw = number of fibers along web thickness
    # nfbf = number of fibers along flange width
    # nftf = number of fibers along flange thickness

    set dw [expr $d - 2 * $tf]
    set y1 [expr -$d/2.0]
    set y2 [expr -$dw/2.0]
    set y3 [expr  $dw/2.0]
    set y4 [expr  $d/2.0]
    
    set z1 [expr -$bf/2.0]
    set z2 [expr -$tw/2.0]
    set z3 [expr  $tw/2.0]
    set z4 [expr  $bf/2.0]

    if {$Orient == "Weak" || $Orient == "YY" } {
	set dw [expr $d - 2 * $tf]
	set z1 [expr -$d/2.0]
	set z2 [expr -$dw/2.0]
	set z3 [expr  $dw/2.0]
	set z4 [expr  $d/2.0]

	set y1 [expr  $bf/2.0]
	set y2 [expr  $tw/2.0]
	set y3 [expr -$tw/2.0]
	set y4 [expr -$bf/2.0]
	
	section fiberSec  $secID  {
	    patch quadr  $matID  $nfbf $nftf   $y1 $z3   $y1 $z4   $y4 $z4   $y4 $z3
	    patch quadr  $matID  $nftw $nfdw   $y2 $z3   $y3 $z3   $y3 $z2   $y2 $z2
	    patch quadr  $matID  $nfbf $nftf   $y1 $z1   $y1 $z2   $y4 $z2   $y4 $z1
	}
	
    } else {
	set dw [expr $d - 2 * $tf]
	set y1 [expr -$d/2.0]
	set y2 [expr -$dw/2.0]
	set y3 [expr  $dw/2.0]
	set y4 [expr  $d/2.0]

	set z1 [expr -$bf/2.0]
	set z2 [expr -$tw/2.0]
	set z3 [expr  $tw/2.0]
	set z4 [expr  $bf/2.0]
	
	section fiberSec  $secID  {
	    #                     nfIJ  nfJK    yI  zI    yJ  zJ    yK  zK    yL  zL
	    patch quadr  $matID  $nfbf $nftf   $y1 $z4   $y1 $z1   $y2 $z1   $y2 $z4
	    patch quadr  $matID  $nftw $nfdw   $y2 $z3   $y2 $z2   $y3 $z2   $y3 $z3
	    patch quadr  $matID  $nfbf $nftf   $y3 $z4   $y3 $z1   $y4 $z1   $y4 $z4
	}
    }
}


  #Winxlb/f "Area(in2) d(in) bf(in) tw(in) tf(in) Ixx(in4) Iyy(in4)"
array set WSection {
    W44X335  	"98.5 44.0 15.9 1.03 1.77 31100 1200 74.7"
    W44X290  	"85.4 43.6 15.8 0.865 1.58 27000 1040 50.9"
    W44X262  	"76.9 43.3 15.8 0.785 1.42 24100 923 37.3"
    W44X230  	"67.7 42.9 15.8 0.710 1.22 20800 796 24.9"
    W40X593  	"174 43.0 16.7 1.79 3.23 50400 2520 445"
    W40X503  	"148 42.1 16.4 1.54 2.76 41600 2040 277"
    W40X431  	"127 41.3 16.2 1.34 2.36 34800 1690 177"
    W40X397  	"117 41.0 16.1 1.22 2.20 32000 1540 142"
    W40X372  	"109 40.6 16.1 1.16 2.05 29600 1420 116"
    W40X362  	"107 40.6 16.0 1.12 2.01 28900 1380 109"
    W40X324  	"95.3 40.2 15.9 1.00 1.81 25600 1220 79.4"
    W40X297  	"87.4 39.8 15.8 0.930 1.65 23200 1090 61.2"
    W40X277  	"81.4 39.7 15.8 0.830 1.58 21900 1040 51.5"
    W40X249  	"73.3 39.4 15.8 0.750 1.42 19600 926 38.1"
    W40X215  	"63.4 39.0 15.8 0.650 1.22 16700 796 24.8"
    W40X199  	"58.5 38.7 15.8 0.650 1.07 14900 695 18.3"
    W40X392  	"115 41.6 12.4 1.42 2.52 29900 803 172"
    W40X331  	"97.5 40.8 12.2 1.22 2.13 24700 644 105"
    W40X327  	"96.0 40.8 12.1 1.18 2.13 24500 640 103"
    W40X294  	"86.3 40.4 12.0 1.06 1.93 21900 562 76.6"
    W40X278  	"82.0 40.2 12.0 1.03 1.81 20500 521 65.0"
    W40X264  	"77.6 40.0 11.9 0.960 1.73 19400 493 56.1"
    W40X235  	"69.0 39.7 11.9 0.830 1.58 17400 444 41.3"
    W40X211  	"62.0 39.4 11.8 0.750 1.42 15500 390 30.4"
    W40X183  	"53.3 39.0 11.8 0.650 1.20 13200 331 19.3"
    W40X167  	"49.2 38.6 11.8 0.650 1.03 11600 283 14.0"
    W40X149  	"43.8 38.2 11.8 0.630 0.830 9800 229 9.36"
    W36X800  	"236 42.6 18.0 2.38 4.29 64700 4200 1060"
    W36X652  	"192 41.1 17.6 1.97 3.54 50600 3230 593"
    W36X529  	"156 39.8 17.2 1.61 2.91 39600 2490 327"
    W36X487  	"143 39.3 17.1 1.50 2.68 36000 2250 258"
    W36X441  	"130 38.9 17.0 1.36 2.44 32100 1990 194"
    W36X395  	"116 38.4 16.8 1.22 2.20 28500 1750 142"
    W36X361  	"106 38.0 16.7 1.12 2.01 25700 1570 109"
    W36X330  	"97.0 37.7 16.6 1.02 1.85 23300 1420 84.3"
    W36X302  	"88.8 37.3 16.7 0.945 1.68 21100 1300 64.3"
    W36X282  	"82.9 37.1 16.6 0.885 1.57 19600 1200 52.7"
    W36X262  	"77.0 36.9 16.6 0.840 1.44 17900 1090 41.6"
    W36X247  	"72.5 36.7 16.5 0.800 1.35 16700 1010 34.7"
    W36X231  	"68.1 36.5 16.5 0.760 1.26 15600 940 28.7"
    W36X256  	"75.4 37.4 12.2 0.960 1.73 16800 528 52.9"
    W36X232  	"68.1 37.1 12.1 0.870 1.57 15000 468 39.6"
    W36X210  	"61.8 36.7 12.2 0.830 1.36 13200 411 28.0"
    W36X194  	"57.0 36.5 12.1 0.765 1.26 12100 375 22.2"
    W36X182  	"53.6 36.3 12.1 0.725 1.18 11300 347 18.5"
    W36X170  	"50.1 36.2 12.0 0.680 1.10 10500 320 15.1"
    W36X160  	"47.0 36.0 12.0 0.650 1.02 9760 295 12.4"
    W36X150  	"44.2 35.9 12.0 0.625 0.940 9040 270 10.1"
    W36X135  	"39.7 35.6 12.0 0.600 0.790 7800 225 7.00"
    W33X387  	"114 36.0 16.2 1.26 2.28 24300 1620 148"
    W33X354  	"104 35.6 16.1 1.16 2.09 22000 1460 115"
    W33X318  	"93.6 35.2 16.0 1.04 1.89 19500 1290 84.4"
    W33X291  	"85.7 34.8 15.9 0.960 1.73 17700 1160 65.1"
    W33X263  	"77.5 34.5 15.8 0.870 1.57 15900 1040 48.7"
    W33X241  	"71.0 34.2 15.9 0.830 1.40 14200 933 36.2"
    W33X221  	"65.2 33.9 15.8 0.775 1.28 12900 840 27.8"
    W33X201  	"59.2 33.7 15.7 0.715 1.15 11600 749 20.8"
    W33X169  	"49.5 33.8 11.5 0.670 1.22 9290 310 17.7"
    W33X152  	"44.8 33.5 11.6 0.635 1.06 8160 273 12.4"
    W33X141  	"41.6 33.3 11.5 0.605 0.960 7450 246 9.70"
    W33X130  	"38.3 33.1 11.5 0.580 0.855 6710 218 7.37"
    W33X118  	"34.7 32.9 11.5 0.550 0.740 5900 187 5.30"
    W30X391  	"115 33.2 15.6 1.36 2.44 20700 1550 173"
    W30X357  	"105 32.8 15.5 1.24 2.24 18700 1390 134"
    W30X326  	"95.8 32.4 15.4 1.14 2.05 16800 1240 103"
    W30X292  	"85.9 32.0 15.3 1.02 1.85 14900 1100 75.2"
    W30X261  	"76.9 31.6 15.2 0.930 1.65 13100 959 54.1"
    W30X235  	"69.2 31.3 15.1 0.830 1.50 11700 855 40.3"
    W30X211  	"62.2 30.9 15.1 0.775 1.32 10300 757 28.4"
    W30X191  	"56.3 30.7 15.0 0.710 1.19 9200 673 21.0"
    W30X173  	"51.0 30.4 15.0 0.655 1.07 8230 598 15.6"
    W30X148  	"43.5 30.7 10.5 0.650 1.18 6680 227 14.5"
    W30X132  	"38.9 30.3 10.5 0.615 1.00 5770 196 9.72"
    W30X124  	"36.5 30.2 10.5 0.585 0.930 5360 181 7.99"
    W30X116  	"34.2 30.0 10.5 0.565 0.850 4930 164 6.43"
    W30X108  	"31.7 29.8 10.5 0.545 0.760 4470 146 4.99"
    W30X99  	"29.1 29.7 10.5 0.520 0.670 3990 128 3.77"
    W30X90  	"26.4 29.5 10.4 0.470 0.610 3610 115 2.84"
    W27X539  	"159 32.5 15.3 1.97 3.54 25600 2110 496"
    W27X368  	"108 30.4 14.7 1.38 2.48 16200 1310 170"
    W27X336  	"98.9 30.0 14.6 1.26 2.28 14600 1180 131"
    W27X307  	"90.4 29.6 14.4 1.16 2.09 13100 1050 101"
    W27X281  	"82.9 29.3 14.4 1.06 1.93 11900 953 79.5"
    W27X258  	"76.0 29.0 14.3 0.980 1.77 10800 859 61.6"
    W27X235  	"69.4 28.7 14.2 0.910 1.61 9700 769 47.0"
    W27X217  	"64.0 28.4 14.1 0.830 1.50 8910 704 37.6"
    W27X194  	"57.2 28.1 14.0 0.750 1.34 7860 619 27.1"
    W27X178  	"52.5 27.8 14.1 0.725 1.19 7020 555 20.1"
    W27X161  	"47.6 27.6 14.0 0.660 1.08 6310 497 15.1"
    W27X146  	"43.1 27.4 14.0 0.605 0.975 5660 443 11.3"
    W27X129  	"37.8 27.6 10.0 0.610 1.10 4760 184 11.1"
    W27X114  	"33.5 27.3 10.1 0.570 0.930 4080 159 7.33"
    W27X102  	"30.0 27.1 10.0 0.515 0.830 3620 139 5.28"
    W27X94  	"27.7 26.9 10.0 0.490 0.745 3270 124 4.03"
    W27X84  	"24.8 26.7 10.0 0.460 0.640 2850 106 2.81"
    W24X370  	"109 28.0 13.7 1.52 2.72 13400 1160 201"
    W24X335  	"98.4 27.5 13.5 1.38 2.48 11900 1030 152"
    W24X306  	"89.8 27.1 13.4 1.26 2.28 10700 919 117"
    W24X279  	"82.0 26.7 13.3 1.16 2.09 9600 823 90.5"
    W24X250  	"73.5 26.3 13.2 1.04 1.89 8490 724 66.6"
    W24X229  	"67.2 26.0 13.1 0.960 1.73 7650 651 51.3"
    W24X207  	"60.7 25.7 13.0 0.870 1.57 6820 578 38.3"
    W24X192  	"56.3 25.5 13.0 0.810 1.46 6260 530 30.8"
    W24X176  	"51.7 25.2 12.9 0.750 1.34 5680 479 23.9"
    W24X162  	"47.7 25.0 13.0 0.705 1.22 5170 443 18.5"
    W24X146  	"43.0 24.7 12.9 0.650 1.09 4580 391 13.4"
    W24X131  	"38.5 24.5 12.9 0.605 0.960 4020 340 9.50"
    W24X117  	"34.4 24.3 12.8 0.550 0.850 3540 297 6.72"
    W24X104  	"30.6 24.1 12.8 0.500 0.750 3100 259 4.72"
    W24X103  	"30.3 24.5 9.00 0.550 0.980 3000 119 7.07"
    W24X94  	"27.7 24.3 9.07 0.515 0.875 2700 109 5.26"
    W24X84  	"24.7 24.1 9.02 0.470 0.770 2370 94.4 3.70"
    W24X76  	"22.4 23.9 8.99 0.440 0.680 2100 82.5 2.68"
    W24X68  	"20.1 23.7 8.97 0.415 0.585 1830 70.4 1.87"
    W24X62  	"18.2 23.7 7.04 0.430 0.590 1550 34.5 1.71"
    W24X55  	"16.2 23.6 7.01 0.395 0.505 1350 29.1 1.18"
    W21X201  	"59.2 23.0 12.6 0.910 1.63 5310 542 40.9"
    W21X182  	"53.6 22.7 12.5 0.830 1.48 4730 483 30.7"
    W21X166  	"48.8 22.5 12.4 0.750 1.36 4280 435 23.6"
    W21X147  	"43.2 22.1 12.5 0.720 1.15 3630 376 15.4"
    W21X132  	"38.8 21.8 12.4 0.650 1.04 3220 333 11.3"
    W21X122  	"35.9 21.7 12.4 0.600 0.960 2960 305 8.98"
    W21X111  	"32.7 21.5 12.3 0.550 0.875 2670 274 6.83"
    W21X101  	"29.8 21.4 12.3 0.500 0.800 2420 248 5.21"
    W21X93  	"27.3 21.6 8.42 0.580 0.930 2070 92.9 6.03"
    W21X83  	"24.3 21.4 8.36 0.515 0.835 1830 81.4 4.34"
    W21X73  	"21.5 21.2 8.30 0.455 0.740 1600 70.6 3.02"
    W21X68  	"20.0 21.1 8.27 0.430 0.685 1480 64.7 2.45"
    W21X62  	"18.3 21.0 8.24 0.400 0.615 1330 57.5 1.83"
    W21X55  	"16.2 20.8 8.22 0.375 0.522 1140 48.4 1.24"
    W21X48  	"14.1 20.6 8.14 0.350 0.430 959 38.7 0.803"
    W21X57  	"16.7 21.1 6.56 0.405 0.650 1170 30.6 1.77"
    W21X50  	"14.7 20.8 6.53 0.380 0.535 984 24.9 1.14"
    W21X44  	"13.0 20.7 6.50 0.350 0.450 843 20.7 0.770"
    W18X311  	"91.6 22.3 12.0 1.52 2.74 6970 795 176"
    W18X283  	"83.3 21.9 11.9 1.40 2.50 6170 704 134"
    W18X258  	"75.9 21.5 11.8 1.28 2.30 5510 628 103"
    W18X234  	"68.8 21.1 11.7 1.16 2.11 4900 558 78.7"
    W18X211  	"62.1 20.7 11.6 1.06 1.91 4330 493 58.6"
    W18X192  	"56.4 20.4 11.5 0.960 1.75 3870 440 44.7"
    W18X175  	"51.3 20.0 11.4 0.890 1.59 3450 391 33.8"
    W18X158  	"46.3 19.7 11.3 0.810 1.44 3060 347 25.2"
    W18X143  	"42.1 19.5 11.2 0.730 1.32 2750 311 19.2"
    W18X130  	"38.2 19.3 11.2 0.670 1.20 2460 278 14.5"
    W18X119  	"35.1 19.0 11.3 0.655 1.06 2190 253 10.6"
    W18X106  	"31.1 18.7 11.2 0.590 0.940 1910 220 7.48"
    W18X97  	"28.5 18.6 11.1 0.535 0.870 1750 201 5.86"
    W18X86  	"25.3 18.4 11.1 0.480 0.770 1530 175 4.10"
    W18X76  	"22.3 18.2 11.0 0.425 0.680 1330 152 2.83"
    W18X71  	"20.8 18.5 7.64 0.495 0.810 1170 60.3 3.49"
    W18X65  	"19.1 18.4 7.59 0.450 0.750 1070 54.8 2.73"
    W18X60  	"17.6 18.2 7.56 0.415 0.695 984 50.1 2.17"
    W18X55  	"16.2 18.1 7.53 0.390 0.630 890 44.9 1.66"
    W18X50  	"14.7 18.0 7.50 0.355 0.570 800 40.1 1.24"
    W18X46  	"13.5 18.1 6.06 0.360 0.605 712 22.5 1.22"
    W18X40  	"11.8 17.9 6.02 0.315 0.525 612 19.1 0.810"
    W18X35  	"10.3 17.7 6.00 0.300 0.425 510 15.3 0.506"
    W16X100  	"29.5 17.0 10.4 0.585 0.985 1490 186 7.73"
    W16X89  	"26.2 16.8 10.4 0.525 0.875 1300 163 5.45"
    W16X77  	"22.6 16.5 10.3 0.455 0.760 1110 138 3.57"
    W16X67  	"19.7 16.3 10.2 0.395 0.665 954 119 2.39"
    W16X57  	"16.8 16.4 7.12 0.430 0.715 758 43.1 2.22"
    W16X50  	"14.7 16.3 7.07 0.380 0.630 659 37.2 1.52"
    W16X45  	"13.3 16.1 7.04 0.345 0.565 586 32.8 1.11"
    W16X40  	"11.8 16.0 7.00 0.305 0.505 518 28.9 0.794"
    W16X36  	"10.6 15.9 6.99 0.295 0.430 448 24.5 0.545"
    W16X31  	"9.13 15.9 5.53 0.275 0.440 375 12.4 0.461"
    W16X26  	"7.68 15.7 5.50 0.250 0.345 301 9.59 0.262"
    W14X730  	"215 22.4 17.9 3.07 4.91 14300 4720 1450"
    W14X665  	"196 21.6 17.7 2.83 4.52 12400 4170 1120"
    W14X605  	"178 20.9 17.4 2.60 4.16 10800 3680 869"
    W14X550  	"162 20.2 17.2 2.38 3.82 9430 3250 669"
    W14X500  	"147 19.6 17.0 2.19 3.50 8210 2880 514"
    W14X455  	"134 19.0 16.8 2.02 3.21 7190 2560 395"
    W14X426  	"125 18.7 16.7 1.88 3.04 6600 2360 331"
    W14X398  	"117 18.3 16.6 1.77 2.85 6000 2170 273"
    W14X370  	"109 17.9 16.5 1.66 2.66 5440 1990 222"
    W14X342  	"101 17.5 16.4 1.54 2.47 4900 1810 178"
    W14X311  	"91.4 17.1 16.2 1.41 2.26 4330 1610 136"
    W14X283  	"83.3 16.7 16.1 1.29 2.07 3840 1440 104"
    W14X257  	"75.6 16.4 16.0 1.18 1.89 3400 1290 79.1"
    W14X233  	"68.5 16.0 15.9 1.07 1.72 3010 1150 59.5"
    W14X211  	"62.0 15.7 15.8 0.980 1.56 2660 1030 44.6"
    W14X193  	"56.8 15.5 15.7 0.890 1.44 2400 931 34.8"
    W14X176  	"51.8 15.2 15.7 0.830 1.31 2140 838 26.5"
    W14X159  	"46.7 15.0 15.6 0.745 1.19 1900 748 19.7"
    W14X145  	"42.7 14.8 15.5 0.680 1.09 1710 677 15.2"
    W14X132  	"38.8 14.7 14.7 0.645 1.03 1530 548 12.3"
    W14X120  	"35.3 14.5 14.7 0.590 0.940 1380 495 9.37"
    W14X109  	"32.0 14.3 14.6 0.525 0.860 1240 447 7.12"
    W14X99  	"29.1 14.2 14.6 0.485 0.780 1110 402 5.37"
    W14X90  	"26.5 14.0 14.5 0.440 0.710 999 362 4.06"
    W14X82  	"24.0 14.3 10.1 0.510 0.855 881 148 5.07"
    W14X74  	"21.8 14.2 10.1 0.450 0.785 795 134 3.87"
    W14X68  	"20.0 14.0 10.0 0.415 0.720 722 121 3.01"
    W14X61  	"17.9 13.9 10.0 0.375 0.645 640 107 2.19"
    W14X53  	"15.6 13.9 8.06 0.370 0.660 541 57.7 1.94"
    W14X48  	"14.1 13.8 8.03 0.340 0.595 484 51.4 1.45"
    W14X43  	"12.6 13.7 8.00 0.305 0.530 428 45.2 1.05"
    W14X38  	"11.2 14.1 6.77 0.310 0.515 385 26.7 0.798"
    W14X34  	"10.0 14.0 6.75 0.285 0.455 340 23.3 0.569"
    W14X30  	"8.85 13.8 6.73 0.270 0.385 291 19.6 0.380"
    W14X26  	"7.69 13.9 5.03 0.255 0.420 245 8.91 0.358"
    W14X22  	"6.49 13.7 5.00 0.230 0.335 199 7.00 0.208"
    W12X336  	"98.8 16.8 13.4 1.78 2.96 4060 1190 243"
    W12X305  	"89.6 16.3 13.2 1.63 2.71 3550 1050 185"
    W12X279  	"81.9 15.9 13.1 1.53 2.47 3110 937 143"
    W12X252  	"74.0 15.4 13.0 1.40 2.25 2720 828 108"
    W12X230  	"67.7 15.1 12.9 1.29 2.07 2420 742 83.8"
    W12X210  	"61.8 14.7 12.8 1.18 1.90 2140 664 64.7"
    W12X190  	"55.8 14.4 12.7 1.06 1.74 1890 589 48.8"
    W12X170  	"50.0 14.0 12.6 0.960 1.56 1650 517 35.6"
    W12X152  	"44.7 13.7 12.5 0.870 1.40 1430 454 25.8"
    W12X136  	"39.9 13.4 12.4 0.790 1.25 1240 398 18.5"
    W12X120  	"35.3 13.1 12.3 0.710 1.11 1070 345 12.9"
    W12X106  	"31.2 12.9 12.2 0.610 0.990 933 301 9.13"
    W12X96  	"28.2 12.7 12.2 0.550 0.900 833 270 6.85"
    W12X87  	"25.6 12.5 12.1 0.515 0.810 740 241 5.10"
    W12X79  	"23.2 12.4 12.1 0.470 0.735 662 216 3.84"
    W12X72  	"21.1 12.3 12.0 0.430 0.670 597 195 2.93"
    W12X65  	"19.1 12.1 12.0 0.390 0.605 533 174 2.18"
    W12X58  	"17.0 12.2 10.0 0.360 0.640 475 107 2.10"
    W12X53  	"15.6 12.1 10.0 0.345 0.575 425 95.8 1.58"
    W12X50  	"14.6 12.2 8.08 0.370 0.640 391 56.3 1.71"
    W12X45  	"13.1 12.1 8.05 0.335 0.575 348 50.0 1.26"
    W12X40  	"11.7 11.9 8.01 0.295 0.515 307 44.1 0.906"
    W12X35  	"10.3 12.5 6.56 0.300 0.520 285 24.5 0.741"
    W12X30  	"8.79 12.3 6.52 0.260 0.440 238 20.3 0.457"
    W12X26  	"7.65 12.2 6.49 0.230 0.380 204 17.3 0.300"
    W12X22  	"6.48 12.3 4.03 0.260 0.425 156 4.66 0.293"
    W12X19  	"5.57 12.2 4.01 0.235 0.350 130 3.76 0.180"
    W12X16  	"4.71 12.0 3.99 0.220 0.265 103 2.82 0.103"
    W12X14  	"4.16 11.9 3.97 0.200 0.225 88.6 2.36 0.0704"
    W10X112  	"32.9 11.4 10.4 0.755 1.25 716 236 15.1"
    W10X100  	"29.4 11.1 10.3 0.680 1.12 623 207 10.9"
    W10X88  	"25.9 10.8 10.3 0.605 0.990 534 179 7.53"
    W10X77  	"22.6 10.6 10.2 0.530 0.870 455 154 5.11"
    W10X68  	"20.0 10.4 10.1 0.470 0.770 394 134 3.56"
    W10X60  	"17.6 10.2 10.1 0.420 0.680 341 116 2.48"
    W10X54  	"15.8 10.1 10.0 0.370 0.615 303 103 1.82"
    W10X49  	"14.4 10.0 10.0 0.340 0.560 272 93.4 1.39"
    W10X45  	"13.3 10.1 8.02 0.350 0.620 248 53.4 1.51"
    W10X39  	"11.5 9.92 7.99 0.315 0.530 209 45.0 0.976"
    W10X33  	"9.71 9.73 7.96 0.290 0.435 171 36.6 0.583"
    W10X30  	"8.84 10.5 5.81 0.300 0.510 170 16.7 0.622"
    W10X26  	"7.61 10.3 5.77 0.260 0.440 144 14.1 0.402"
    W10X22  	"6.49 10.2 5.75 0.240 0.360 118 11.4 0.239"
    W10X19  	"5.62 10.2 4.02 0.250 0.395 96.3 4.29 0.233"
    W10X17  	"4.99 10.1 4.01 0.240 0.330 81.9 3.56 0.156"
    W10X15  	"4.41 10.0 4.00 0.230 0.270 68.9 2.89 0.104"
    W10X12  	"3.54 9.87 3.96 0.190 0.210 53.8 2.18 0.0547"
    W8X67  	"19.7 9.00 8.28 0.570 0.935 272 88.6 5.05"
    W8X58  	"17.1 8.75 8.22 0.510 0.810 228 75.1 3.33"
    W8X48  	"14.1 8.50 8.11 0.400 0.685 184 60.9 1.96"
    W8X40  	"11.7 8.25 8.07 0.360 0.560 146 49.1 1.12"
    W8X35  	"10.3 8.12 8.02 0.310 0.495 127 42.6 0.769"
    W8X31  	"9.12 8.00 8.00 0.285 0.435 110 37.1 0.536"
    W8X28  	"8.24 8.06 6.54 0.285 0.465 98.0 21.7 0.537"
    W8X24  	"7.08 7.93 6.50 0.245 0.400 82.7 18.3 0.346"
    W8X21  	"6.16 8.28 5.27 0.250 0.400 75.3 9.77 0.282"
    W8X18  	"5.26 8.14 5.25 0.230 0.330 61.9 7.97 0.172"
    W8X15  	"4.44 8.11 4.02 0.245 0.315 48.0 3.41 0.137"
    W8X13  	"3.84 7.99 4.00 0.230 0.255 39.6 2.73 0.0871"
    W8X10  	"2.96 7.89 3.94 0.170 0.205 30.8 2.09 0.0426"
    W6X25  	"7.34 6.38 6.08 0.320 0.455 53.4 17.1 0.461"
    W6X20  	"5.87 6.20 6.02 0.260 0.365 41.4 13.3 0.240"
    W6X15  	"4.43 5.99 5.99 0.230 0.260 29.1 9.32 0.101"
    W6X16  	"4.74 6.28 4.03 0.260 0.405 32.1 4.43 0.223"
    W6X12  	"3.55 6.03 4.00 0.230 0.280 22.1 2.99 0.0903"
    W6X9  	"2.68 5.90 3.94 0.170 0.215 16.4 2.20 0.0405"
    W6X8.5  	"2.52 5.83 3.94 0.170 0.195 14.9 1.99 0.0333"
    W5X19  	"5.56 5.15 5.03 0.270 0.430 26.3 9.13 0.316"
    W5X16  	"4.71 5.01 5.00 0.240 0.360 21.4 7.51 0.192"
    W4X13  	"3.83 4.16 4.06 0.280 0.345 11.3 3.86 0.151"
}
